@@ -55,6 +55,7 @@
 #include <windows.h>
 #endif
 
+#include "base/global.h"
 #include "base/logger.h"
 #include "base/preferences.h"
 #include "base/profile.h"
@@ -77,7 +78,7 @@ namespace
     ListType setToEntryList(const QSet<QString> &input)
     {
         ListType entryList;
-        foreach (const QString &setValue, input)
+        for (const QString &setValue : input)
             entryList.emplace_back(setValue.toStdString());
         return entryList;
     }
@@ -158,14 +159,14 @@ namespace
 {
     // new constructor is available
     template<typename T, typename std::enable_if<std::is_constructible<T, libt::torrent_info, bool>::value, int>::type = 0>
-    T makeTorrentCreator(const libtorrent::torrent_info & ti)
+    T makeTorrentCreator(const libtorrent::torrent_info &ti)
     {
         return T(ti, true);
     }
 
     // new constructor isn't available
     template<typename T, typename std::enable_if<!std::is_constructible<T, libt::torrent_info, bool>::value, int>::type = 0>
-    T makeTorrentCreator(const libtorrent::torrent_info & ti)
+    T makeTorrentCreator(const libtorrent::torrent_info &ti)
     {
         return T(ti);
     }
@@ -190,7 +191,7 @@ TorrentHandle::TorrentHandle(Session *session, const libtorrent::torrent_handle
     , m_hasMissingFiles(false)
     , m_hasRootFolder(params.hasRootFolder)
     , m_needsToSetFirstLastPiecePriority(false)
-    , m_pauseAfterRecheck(false)
+    , m_needsToStartForced(params.forced)
 {
     if (m_useAutoTMM)
         m_savePath = Utils::Fs::toNativePath(m_session->categorySavePath(m_category));
@@ -220,14 +221,14 @@ TorrentHandle::TorrentHandle(Session *session, const libtorrent::torrent_handle
     // When torrent added/restored in "paused" state it become "started" immediately after construction.
     // When it is added/restored in "resumed" state, it become "started" after it is really resumed
     // (i.e. after receiving "torrent resumed" alert).
-    m_started = (params.restored && hasMetadata() ? isPaused() : params.paused);
-
-    if (!m_started) {
-        if (!params.restored || !hasMetadata()) {
-            // Resume torrent because it was added in "resumed" state
-            // but it's actually paused during initialization
-            resume(params.forced);
-        }
+    if (params.paused) {
+        m_startupState = Started;
+    }
+    else if (!params.restored || !hasMetadata()) {
+        // Resume torrent because it was added in "resumed" state
+        // but it's actually paused during initialization
+        m_startupState = Starting;
+        resume(params.forced);
     }
 }
 
@@ -374,10 +375,9 @@ QString TorrentHandle::nativeActualSavePath() const
 QList<TrackerEntry> TorrentHandle::trackers() const
 {
     QList<TrackerEntry> entries;
-    std::vector<libt::announce_entry> announces;
+    const std::vector<libt::announce_entry> announces = m_nativeHandle.trackers();
 
-    announces = m_nativeHandle.trackers();
-    foreach (const libt::announce_entry &tracker, announces)
+    for (const libt::announce_entry &tracker : announces)
         entries << tracker;
 
     return entries;
@@ -391,7 +391,7 @@ QHash<QString, TrackerInfo> TorrentHandle::trackerInfos() const
 void TorrentHandle::addTrackers(const QList<TrackerEntry> &trackers)
 {
     QList<TrackerEntry> addedTrackers;
-    foreach (const TrackerEntry &tracker, trackers) {
+    for (const TrackerEntry &tracker : trackers) {
         if (addTracker(tracker))
             addedTrackers << tracker;
     }
@@ -400,13 +400,13 @@ void TorrentHandle::addTrackers(const QList<TrackerEntry> &trackers)
         m_session->handleTorrentTrackersAdded(this, addedTrackers);
 }
 
-void TorrentHandle::replaceTrackers(QList<TrackerEntry> trackers)
+void TorrentHandle::replaceTrackers(const QList<TrackerEntry> &trackers)
 {
     QList<TrackerEntry> existingTrackers = this->trackers();
     QList<TrackerEntry> addedTrackers;
 
     std::vector<libt::announce_entry> announces;
-    foreach (const TrackerEntry &tracker, trackers) {
+    for (const TrackerEntry &tracker : trackers) {
         announces.push_back(tracker.nativeEntry());
         if (!existingTrackers.contains(tracker))
             addedTrackers << tracker;
@@ -438,9 +438,9 @@ bool TorrentHandle::addTracker(const TrackerEntry &tracker)
 QList<QUrl> TorrentHandle::urlSeeds() const
 {
     QList<QUrl> urlSeeds;
-    std::set<std::string> seeds = m_nativeHandle.url_seeds();
+    const std::set<std::string> seeds = m_nativeHandle.url_seeds();
 
-    foreach (const std::string &urlSeed, seeds)
+    for (const std::string &urlSeed : seeds)
         urlSeeds.append(QUrl(urlSeed.c_str()));
 
     return urlSeeds;
@@ -449,7 +449,7 @@ QList<QUrl> TorrentHandle::urlSeeds() const
 void TorrentHandle::addUrlSeeds(const QList<QUrl> &urlSeeds)
 {
     QList<QUrl> addedUrlSeeds;
-    foreach (const QUrl &urlSeed, urlSeeds) {
+    for (const QUrl &urlSeed : urlSeeds) {
         if (addUrlSeed(urlSeed))
             addedUrlSeeds << urlSeed;
     }
@@ -461,7 +461,7 @@ void TorrentHandle::addUrlSeeds(const QList<QUrl> &urlSeeds)
 void TorrentHandle::removeUrlSeeds(const QList<QUrl> &urlSeeds)
 {
     QList<QUrl> removedUrlSeeds;
-    foreach (const QUrl &urlSeed, urlSeeds) {
+    for (const QUrl &urlSeed : urlSeeds) {
         if (removeUrlSeed(urlSeed))
             removedUrlSeeds << urlSeed;
     }
@@ -596,8 +596,7 @@ bool TorrentHandle::removeTag(const QString &tag)
 
 void TorrentHandle::removeAllTags()
 {
-    // QT automatically copies the container in foreach, so it's safe to mutate it.
-    foreach (const QString &tag, m_tags)
+    for (const QString &tag : asConst(tags()))
         removeTag(tag);
 }
 
@@ -623,7 +622,7 @@ QString TorrentHandle::filePath(int index) const
 
 QString TorrentHandle::fileName(int index) const
 {
-    if (!hasMetadata()) return  QString();
+    if (!hasMetadata()) return QString();
     return Utils::Fs::fileName(filePath(index));
 }
 
@@ -636,7 +635,7 @@ qlonglong TorrentHandle::fileSize(int index) const
 // to all files in a torrent
 QStringList TorrentHandle::absoluteFilePaths() const
 {
-    if (!hasMetadata()) return  QStringList();
+    if (!hasMetadata()) return QStringList();
 
     QDir saveDir(savePath(true));
     QStringList res;
@@ -647,7 +646,7 @@ QStringList TorrentHandle::absoluteFilePaths() const
 
 QStringList TorrentHandle::absoluteFilePathsUnwanted() const
 {
-    if (!hasMetadata()) return  QStringList();
+    if (!hasMetadata()) return QStringList();
 
     QDir saveDir(savePath(true));
     QStringList res;
@@ -807,7 +806,10 @@ TorrentState TorrentHandle::state() const
 
 void TorrentHandle::updateState()
 {
-    if (isMoveInProgress()) {
+    if (m_nativeStatus.state == libt::torrent_status::checking_resume_data) {
+        m_state = TorrentState::CheckingResumeData;
+    }
+    else if (isMoveInProgress()) {
         m_state = TorrentState::Moving;
     }
     else if (isPaused()) {
@@ -839,9 +841,6 @@ void TorrentHandle::updateState()
                 m_state = TorrentState::QueuedForChecking;
                 break;
 #endif
-            case libt::torrent_status::checking_resume_data:
-                m_state = TorrentState::CheckingResumeData;
-                break;
             case libt::torrent_status::checking_files:
                 m_state = m_hasSeedStatus ? TorrentState::CheckingUploading : TorrentState::CheckingDownloading;
                 break;
@@ -883,9 +882,9 @@ bool TorrentHandle::hasError() const
 
 bool TorrentHandle::hasFilteredPieces() const
 {
-    std::vector<int> pp = m_nativeHandle.piece_priorities();
+    const std::vector<int> pp = m_nativeHandle.piece_priorities();
 
-    foreach (const int priority, pp)
+    for (const int priority : pp)
         if (priority == 0) return true;
 
     return false;
@@ -973,12 +972,13 @@ qulonglong TorrentHandle::eta() const
 QVector<qreal> TorrentHandle::filesProgress() const
 {
     std::vector<boost::int64_t> fp;
-    QVector<qreal> result;
     m_nativeHandle.file_progress(fp, libt::torrent_handle::piece_granularity);
 
-    int count = static_cast<int>(fp.size());
+    const int count = static_cast<int>(fp.size());
+    QVector<qreal> result;
+    result.reserve(count);
     for (int i = 0; i < count; ++i) {
-        qlonglong size = fileSize(i);
+        const qlonglong size = fileSize(i);
         if ((size <= 0) || (fp[i] == size))
             result << 1;
         else
@@ -1086,7 +1086,7 @@ QList<PeerInfo> TorrentHandle::peers() const
 
     m_nativeHandle.get_peer_info(nativePeers);
 
-    foreach (const libt::peer_info &peer, nativePeers)
+    for (const libt::peer_info &peer : nativePeers)
         peers << PeerInfo(this, peer);
 
     return peers;
@@ -1270,12 +1270,13 @@ void TorrentHandle::forceRecheck()
 {
     if (!hasMetadata()) return;
 
+    m_nativeHandle.force_recheck();
+    m_unchecked = false;
+
     if (isPaused()) {
-        m_pauseAfterRecheck = true;
+        m_nativeHandle.stop_when_ready(true);
         resume_impl(true, true);
     }
-
-    m_nativeHandle.force_recheck();
 }
 
 void TorrentHandle::setSequentialDownload(bool b)
@@ -1360,7 +1361,12 @@ void TorrentHandle::resume_impl(bool forced, bool uploadMode)
 {
     if (hasError())
         m_nativeHandle.clear_error();
-    m_hasMissingFiles = false;
+
+    if (m_hasMissingFiles) {
+        m_hasMissingFiles = false;
+        m_nativeHandle.force_recheck();
+    }
+
     m_nativeHandle.auto_managed(!forced);
     m_nativeHandle.set_upload_mode(uploadMode);
     m_nativeHandle.resume();
@@ -1418,16 +1424,6 @@ bool TorrentHandle::saveTorrentFile(const QString &path)
     return false;
 }
 
-void TorrentHandle::setFilePriority(int index, int priority)
-{
-    std::vector<int> priorities = m_nativeHandle.file_priorities();
-
-    if ((priorities.size() > static_cast<quint64>(index)) && (priorities[index] != priority)) {
-        priorities[index] = priority;
-        prioritizeFiles(QVector<int>::fromStdVector(priorities));
-    }
-}
-
 void TorrentHandle::handleStateUpdate(const libt::torrent_status &nativeStatus)
 {
     updateStatus(nativeStatus);
@@ -1552,21 +1548,32 @@ void TorrentHandle::handleTrackerErrorAlert(const libtorrent::tracker_error_aler
 void TorrentHandle::handleTorrentCheckedAlert(const libtorrent::torrent_checked_alert *p)
 {
     Q_UNUSED(p);
-    qDebug("%s have just finished checking", qUtf8Printable(hash()));
+    qDebug("\"%s\" have just finished checking", qUtf8Printable(name()));
+
+    if (m_startupState == NotStarted) {
+        if (!m_hasMissingFiles) {
+            // Resume torrent because it was added in "resumed" state
+            // but it's actually paused during initialization.
+            m_startupState = Starting;
+            resume(m_needsToStartForced);
+        }
+        else {
+            // Torrent that has missing files is marked as "started"
+            // but it remains paused.
+            m_startupState = Started;
+        }
+    }
 
     updateStatus();
 
-    if ((progress() < 1.0) && (wantedSize() > 0))
-        m_hasSeedStatus = false;
-    else if (progress() == 1.0)
-        m_hasSeedStatus = true;
+    if (!m_hasMissingFiles) {
+        if ((progress() < 1.0) && (wantedSize() > 0))
+            m_hasSeedStatus = false;
+        else if (progress() == 1.0)
+            m_hasSeedStatus = true;
 
-    adjustActualSavePath();
-    manageIncompleteFiles();
-
-    if (m_pauseAfterRecheck) {
-        m_pauseAfterRecheck = false;
-        pause();
+        adjustActualSavePath();
+        manageIncompleteFiles();
     }
 
     m_session->handleTorrentChecked(this);
@@ -1575,7 +1582,7 @@ void TorrentHandle::handleTorrentCheckedAlert(const libtorrent::torrent_checked_
 void TorrentHandle::handleTorrentFinishedAlert(const libtorrent::torrent_finished_alert *p)
 {
     Q_UNUSED(p);
-    qDebug("Got a torrent finished alert for %s", qUtf8Printable(name()));
+    qDebug("Got a torrent finished alert for \"%s\"", qUtf8Printable(name()));
     qDebug("Torrent has seed status: %s", m_hasSeedStatus ? "yes" : "no");
     if (m_hasSeedStatus) return;
 
@@ -1587,13 +1594,13 @@ void TorrentHandle::handleTorrentFinishedAlert(const libtorrent::torrent_finishe
     manageIncompleteFiles();
 
     const bool recheckTorrentsOnCompletion = Preferences::instance()->recheckTorrentsOnCompletion();
-    if (isMoveInProgress() || m_renameCount > 0) {
+    if (isMoveInProgress() || (m_renameCount > 0)) {
         if (recheckTorrentsOnCompletion)
             m_moveFinishedTriggers.append(boost::bind(&TorrentHandle::forceRecheck, this));
         m_moveFinishedTriggers.append(boost::bind(&Session::handleTorrentFinished, m_session, this));
     }
     else {
-        if (recheckTorrentsOnCompletion)
+        if (recheckTorrentsOnCompletion && m_unchecked)
             forceRecheck();
         m_session->handleTorrentFinished(this);
     }
@@ -1602,19 +1609,22 @@ void TorrentHandle::handleTorrentFinishedAlert(const libtorrent::torrent_finishe
 void TorrentHandle::handleTorrentPausedAlert(const libtorrent::torrent_paused_alert *p)
 {
     Q_UNUSED(p);
-    updateStatus();
-    m_speedMonitor.reset();
-    m_session->handleTorrentPaused(this);
+
+    if (m_startupState == Started) {
+        updateStatus();
+        m_speedMonitor.reset();
+        m_session->handleTorrentPaused(this);
+    }
 }
 
 void TorrentHandle::handleTorrentResumedAlert(const libtorrent::torrent_resumed_alert *p)
 {
     Q_UNUSED(p);
 
-    if (m_started)
+    if (m_startupState == Started)
         m_session->handleTorrentResumed(this);
-    else
-        m_started = true;
+    else if (m_startupState == Starting)
+        m_startupState = Started;
 }
 
 void TorrentHandle::handleSaveResumeDataAlert(const libtorrent::save_resume_data_alert *p)
@@ -1665,7 +1675,6 @@ void TorrentHandle::handleFastResumeRejectedAlert(const libtorrent::fastresume_r
 {
     if (p->error.value() == libt::errors::mismatching_file_size) {
         // Mismatching file size (files were probably moved)
-        pause();
         m_hasMissingFiles = true;
         LogMsg(tr("File sizes mismatch for torrent '%1', pausing it.").arg(name()), Log::CRITICAL);
     }
@@ -1700,7 +1709,9 @@ void TorrentHandle::handleFileRenamedAlert(const libtorrent::file_renamed_alert
         }
     }
 
-    updateStatus();
+    // We don't really need to call updateStatus() in this place.
+    // All we need to do is make sure we have a valid instance of the TorrentInfo object.
+    m_torrentInfo = TorrentInfo {m_nativeHandle.torrent_file()};
 
     --m_renameCount;
     while (!isMoveInProgress() && (m_renameCount == 0) && !m_moveFinishedTriggers.isEmpty())
@@ -1718,7 +1729,9 @@ void TorrentHandle::handleFileRenameFailedAlert(const libtorrent::file_rename_fa
 
 void TorrentHandle::handleFileCompletedAlert(const libtorrent::file_completed_alert *p)
 {
-    updateStatus();
+    // We don't really need to call updateStatus() in this place.
+    // All we need to do is make sure we have a valid instance of the TorrentInfo object.
+    m_torrentInfo = TorrentInfo {m_nativeHandle.torrent_file()};
 
     qDebug("A file completed download in torrent \"%s\"", qUtf8Printable(name()));
     if (m_session->isAppendExtensionEnabled()) {
@@ -1933,6 +1946,13 @@ void TorrentHandle::updateStatus(const libtorrent::torrent_status &nativeStatus)
 
     updateState();
     updateTorrentInfo();
+
+    // NOTE: Don't change the order of these conditionals!
+    // Otherwise it will not work properly since torrent can be CheckingDownloading.
+    if (isChecking())
+        m_unchecked = false;
+    else if (isDownloading())
+        m_unchecked = true;
 }
 
 void TorrentHandle::setRatioLimit(qreal limit)
@@ -1974,8 +1994,6 @@ void TorrentHandle::setDownloadLimit(int limit)
 void TorrentHandle::setSuperSeeding(bool enable)
 {
     m_nativeHandle.super_seeding(enable);
-    if (superSeeding() != enable)
-        updateStatus();
 }
 
 void TorrentHandle::flushCache()
@@ -2034,7 +2052,7 @@ void TorrentHandle::prioritizeFiles(const QVector<int> &priorities)
                 if (created) {
                     // Hide the folder on Windows
                     qDebug() << "Hiding folder (Windows)";
-                    std::wstring winPath =  Utils::Fs::toNativePath(unwantedAbsPath).toStdWString();
+                    std::wstring winPath = Utils::Fs::toNativePath(unwantedAbsPath).toStdWString();
                     DWORD dwAttrs = ::GetFileAttributesW(winPath.c_str());
                     bool ret = ::SetFileAttributesW(winPath.c_str(), dwAttrs | FILE_ATTRIBUTE_HIDDEN);
                     Q_ASSERT(ret != 0); Q_UNUSED(ret);
@@ -2068,13 +2086,11 @@ void TorrentHandle::prioritizeFiles(const QVector<int> &priorities)
     // Restore first/last piece first option if necessary
     if (firstLastPieceFirst)
         setFirstLastPiecePriorityImpl(true, priorities);
-
-    updateStatus();
 }
 
 QVector<qreal> TorrentHandle::availableFileFractions() const
 {
-    const auto filesCount = this->filesCount();
+    const int filesCount = this->filesCount();
     if (filesCount < 0) return {};
 
     const QVector<int> piecesAvailability = pieceAvailability();
@@ -2083,12 +2099,13 @@ QVector<qreal> TorrentHandle::availableFileFractions() const
 
     QVector<qreal> res;
     res.reserve(filesCount);
-    TorrentInfo info = this->info();
-    for (int file = 0; file < filesCount; ++file) {
-        TorrentInfo::PieceRange filePieces = info.filePieces(file);
+    const TorrentInfo info = this->info();
+    for (int i = 0; i < filesCount; ++i) {
+        const TorrentInfo::PieceRange filePieces = info.filePieces(i);
+
         int availablePieces = 0;
         for (int piece = filePieces.first(); piece <= filePieces.last(); ++piece) {
-            availablePieces += piecesAvailability[piece] > 0 ? 1 : 0;
+            availablePieces += (piecesAvailability[piece] > 0) ? 1 : 0;
         }
         res.push_back(static_cast<qreal>(availablePieces) / filePieces.size());
     }
