@@ -40,6 +40,8 @@
 #include <QThreadStorage>
 #endif
 
+#include "../tristatebool.h"
+
 namespace
 {
     class NaturalCompare
@@ -85,7 +87,10 @@ namespace
 
                 const QChar leftChar = (m_caseSensitivity == Qt::CaseSensitive) ? left[posL] : left[posL].toLower();
                 const QChar rightChar = (m_caseSensitivity == Qt::CaseSensitive) ? right[posR] : right[posR].toLower();
-                if (leftChar == rightChar) {
+                // Compare only non-digits.
+                // Numbers should be compared as a whole
+                // otherwise the string->int conversion can yield a wrong value
+                if ((leftChar == rightChar) && !leftChar.isDigit()) {
                     // compare next character
                     ++posL;
                     ++posR;
@@ -167,7 +172,7 @@ bool Utils::String::slowEquals(const QByteArray &a, const QByteArray &b)
     int lengthB = b.length();
 
     int diff = lengthA ^ lengthB;
-    for (int i = 0; (i < lengthA) && (i < lengthB); i++)
+    for (int i = 0; (i < lengthA) && (i < lengthB); ++i)
         diff |= a[i] ^ b[i];
 
     return (diff == 0);
@@ -181,3 +186,19 @@ QString Utils::String::wildcardToRegex(const QString &pattern)
 {
     return qt_regexp_toCanonical(pattern, QRegExp::Wildcard);
 }
+
+bool Utils::String::parseBool(const QString &string, const bool defaultValue)
+{
+    if (defaultValue)
+        return (string.compare("false", Qt::CaseInsensitive) == 0) ? false : true;
+    return (string.compare("true", Qt::CaseInsensitive) == 0) ? true : false;
+}
+
+TriStateBool Utils::String::parseTriStateBool(const QString &string)
+{
+    if (string.compare("true", Qt::CaseInsensitive) == 0)
+        return TriStateBool::True;
+    if (string.compare("false", Qt::CaseInsensitive) == 0)
+        return TriStateBool::False;
+    return TriStateBool::Undefined;
+}
