@@ -60,7 +60,7 @@ namespace Utils
         {
             if (str.length() < 2) return str;
 
-            for (auto const quote : quotes) {
+            for (const auto &quote : quotes) {
                 if (str.startsWith(quote) && str.endsWith(quote))
                     return str.mid(1, str.length() - 2);
             }
