@@ -71,6 +71,21 @@
 #include "ui_optionsdialog.h"
 #include "utils.h"
 
+namespace
+{
+    QStringList translatedWeekdayNames()
+    {
+        // return translated strings from Monday to Sunday in user selected locale
+
+        const QLocale locale {Preferences::instance()->getLocale()};
+        const QDate date {2018, 11, 5};  // Monday
+        QStringList ret;
+        for (int i = 0; i < 7; ++i)
+            ret.append(locale.toString(date.addDays(i), "dddd"));
+        return ret;
+    }
+}
+
 class WheelEventEater : public QObject
 {
 public:
@@ -145,10 +160,10 @@ OptionsDialog::OptionsDialog(QWidget *parent)
     m_ui->hsplitter->setCollapsible(0, false);
     m_ui->hsplitter->setCollapsible(1, false);
     // Get apply button in button box
-    QList<QAbstractButton *> buttons = m_ui->buttonBox->buttons();
-    foreach (QAbstractButton *button, buttons) {
+    const QList<QAbstractButton *> buttons = m_ui->buttonBox->buttons();
+    for (QAbstractButton *button : buttons) {
         if (m_ui->buttonBox->buttonRole(button) == QDialogButtonBox::ApplyRole) {
-            applyButton = button;
+            m_applyButton = button;
             break;
         }
     }
@@ -164,8 +179,7 @@ OptionsDialog::OptionsDialog(QWidget *parent)
     initializeLanguageCombo();
 
     // Load week days (scheduler)
-    for (uint i = 1; i <= 7; ++i)
-        m_ui->comboBoxScheduleDays->addItem(QDate::longDayName(i, QDate::StandaloneFormat));
+    m_ui->comboBoxScheduleDays->addItems(translatedWeekdayNames());
 
     // Load options
     loadOptions();
@@ -306,10 +320,6 @@ OptionsDialog::OptionsDialog(QWidget *parent)
     connect(m_ui->spinPort, qSpinBoxValueChanged, this, &ThisType::enableApplyButton);
     connect(m_ui->checkRandomPort, &QAbstractButton::toggled, this, &ThisType::enableApplyButton);
     connect(m_ui->checkUPnP, &QAbstractButton::toggled, this, &ThisType::enableApplyButton);
-    connect(m_ui->checkUploadLimit, &QAbstractButton::toggled, this, &ThisType::enableApplyButton);
-    connect(m_ui->checkDownloadLimit, &QAbstractButton::toggled, this, &ThisType::enableApplyButton);
-    connect(m_ui->checkUploadLimitAlt, &QAbstractButton::toggled, this, &ThisType::enableApplyButton);
-    connect(m_ui->checkDownloadLimitAlt, &QAbstractButton::toggled, this, &ThisType::enableApplyButton);
     connect(m_ui->spinUploadLimit, qSpinBoxValueChanged, this, &ThisType::enableApplyButton);
     connect(m_ui->spinDownloadLimit, qSpinBoxValueChanged, this, &ThisType::enableApplyButton);
     connect(m_ui->spinUploadLimitAlt, qSpinBoxValueChanged, this, &ThisType::enableApplyButton);
@@ -394,6 +404,7 @@ OptionsDialog::OptionsDialog(QWidget *parent)
     connect(m_ui->checkBypassAuthSubnetWhitelist, &QAbstractButton::toggled, m_ui->IPSubnetWhitelistButton, &QPushButton::setEnabled);
     connect(m_ui->checkClickjacking, &QCheckBox::toggled, this, &ThisType::enableApplyButton);
     connect(m_ui->checkCSRFProtection, &QCheckBox::toggled, this, &ThisType::enableApplyButton);
+    connect(m_ui->groupHostHeaderValidation, &QGroupBox::toggled, this, &ThisType::enableApplyButton);
     connect(m_ui->checkDynDNS, &QGroupBox::toggled, this, &ThisType::enableApplyButton);
     connect(m_ui->comboDNSService, qComboBoxCurrentIndexChanged, this, &ThisType::enableApplyButton);
     connect(m_ui->domainNameTxt, &QLineEdit::textChanged, this, &ThisType::enableApplyButton);
@@ -407,18 +418,19 @@ OptionsDialog::OptionsDialog(QWidget *parent)
     connect(m_ui->checkRSSEnable, &QCheckBox::toggled, this, &OptionsDialog::enableApplyButton);
     connect(m_ui->checkRSSAutoDownloaderEnable, &QCheckBox::toggled, this, &OptionsDialog::enableApplyButton);
     connect(m_ui->textSmartEpisodeFilters, &QPlainTextEdit::textChanged, this, &OptionsDialog::enableApplyButton);
+    connect(m_ui->checkSmartFilterDownloadRepacks, &QCheckBox::toggled, this, &OptionsDialog::enableApplyButton);
     connect(m_ui->spinRSSRefreshInterval, qSpinBoxValueChanged, this, &OptionsDialog::enableApplyButton);
     connect(m_ui->spinRSSMaxArticlesPerFeed, qSpinBoxValueChanged, this, &OptionsDialog::enableApplyButton);
     connect(m_ui->btnEditRules, &QPushButton::clicked, this, [this]() { AutomatedRssDownloader(this).exec(); });
 
     // Disable apply Button
-    applyButton->setEnabled(false);
+    m_applyButton->setEnabled(false);
     // Tab selection mechanism
     connect(m_ui->tabSelection, &QListWidget::currentItemChanged, this, &ThisType::changePage);
     // Load Advanced settings
-    advancedSettings = new AdvancedSettings(m_ui->tabAdvancedPage);
-    m_ui->advPageLayout->addWidget(advancedSettings);
-    connect(advancedSettings, &AdvancedSettings::settingsChanged, this, &ThisType::enableApplyButton);
+    m_advancedSettings = new AdvancedSettings(m_ui->tabAdvancedPage);
+    m_ui->advPageLayout->addWidget(m_advancedSettings);
+    connect(m_advancedSettings, &AdvancedSettings::settingsChanged, this, &ThisType::enableApplyButton);
 
     m_ui->textFileLogPath->setDialogCaption(tr("Choose a save directory"));
     m_ui->textFileLogPath->setMode(FileSystemPathEdit::Mode::DirectorySave);
@@ -441,9 +453,9 @@ OptionsDialog::OptionsDialog(QWidget *parent)
 
     // disable mouse wheel event on widgets to avoid mis-selection
     WheelEventEater *wheelEventEater = new WheelEventEater(this);
-    for (QComboBox *widget : copyAsConst(findChildren<QComboBox *>()))
+    for (QComboBox *widget : asConst(findChildren<QComboBox *>()))
         widget->installEventFilter(wheelEventEater);
-    for (QSpinBox *widget : copyAsConst(findChildren<QSpinBox *>()))
+    for (QSpinBox *widget : asConst(findChildren<QSpinBox *>()))
         widget->installEventFilter(wheelEventEater);
 
     loadWindowState();
@@ -457,7 +469,7 @@ void OptionsDialog::initializeLanguageCombo()
     // List language files
     const QDir langDir(":/lang");
     const QStringList langFiles = langDir.entryList(QStringList("qbittorrent_*.qm"), QDir::Files);
-    foreach (const QString langFile, langFiles) {
+    for (const QString &langFile : langFiles) {
         QString localeStr = langFile.mid(12); // remove "qbittorrent_"
         localeStr.chop(3); // Remove ".qm"
         QString languageName;
@@ -481,7 +493,7 @@ OptionsDialog::~OptionsDialog()
 
     saveWindowState();
 
-    foreach (const QString &path, addedScanDirs)
+    for (const QString &path : asConst(m_addedScanDirs))
         ScanFoldersModel::instance()->removePath(path);
     ScanFoldersModel::instance()->configure(); // reloads "removed" paths
     delete m_ui;
@@ -529,7 +541,7 @@ void OptionsDialog::saveWindowState() const
 
 void OptionsDialog::saveOptions()
 {
-    applyButton->setEnabled(false);
+    m_applyButton->setEnabled(false);
     Preferences *const pref = Preferences::instance();
     // Load the translation
     QString locale = getLocale();
@@ -553,8 +565,8 @@ void OptionsDialog::saveOptions()
     pref->setTrayIconStyle(TrayIcon::Style(m_ui->comboTrayIcon->currentIndex()));
     pref->setCloseToTray(closeToTray());
     pref->setMinimizeToTray(minimizeToTray());
-    pref->setStartMinimized(startMinimized());
 #endif
+    pref->setStartMinimized(startMinimized());
     pref->setSplashScreenDisabled(isSplashScreenDisabled());
     pref->setConfirmOnExit(m_ui->checkProgramExitConfirm->isChecked());
     pref->setDontConfirmAutoExit(!m_ui->checkProgramAutoExitConfirm->isChecked());
@@ -593,6 +605,7 @@ void OptionsDialog::saveOptions()
     RSS::Session::instance()->setProcessingEnabled(m_ui->checkRSSEnable->isChecked());
     RSS::AutoDownloader::instance()->setProcessingEnabled(m_ui->checkRSSAutoDownloaderEnable->isChecked());
     RSS::AutoDownloader::instance()->setSmartEpisodeFilters(m_ui->textSmartEpisodeFilters->toPlainText().split('\n', QString::SplitBehavior::SkipEmptyParts));
+    RSS::AutoDownloader::instance()->setDownloadRepacks(m_ui->checkSmartFilterDownloadRepacks->isChecked());
 
     auto session = BitTorrent::Session::instance();
 
@@ -612,11 +625,11 @@ void OptionsDialog::saveOptions()
     AddNewTorrentDialog::setTopLevel(m_ui->checkAdditionDialogFront->isChecked());
     session->setAddTorrentPaused(addTorrentsInPause());
     session->setCreateTorrentSubfolder(m_ui->checkCreateSubfolder->isChecked());
-    ScanFoldersModel::instance()->removeFromFSWatcher(removedScanDirs);
-    ScanFoldersModel::instance()->addToFSWatcher(addedScanDirs);
+    ScanFoldersModel::instance()->removeFromFSWatcher(m_removedScanDirs);
+    ScanFoldersModel::instance()->addToFSWatcher(m_addedScanDirs);
     ScanFoldersModel::instance()->makePersistent();
-    removedScanDirs.clear();
-    addedScanDirs.clear();
+    m_removedScanDirs.clear();
+    m_addedScanDirs.clear();
     session->setTorrentExportDirectory(getTorrentExportDir());
     session->setFinishedTorrentExportDirectory(getFinishedTorrentExportDir());
     pref->setMailNotificationEnabled(m_ui->groupMailNotification->isChecked());
@@ -641,15 +654,13 @@ void OptionsDialog::saveOptions()
     session->setPort(getPort());
     session->setUseRandomPort(m_ui->checkRandomPort->isChecked());
     Net::PortForwarder::instance()->setEnabled(isUPnPEnabled());
-    const QPair<int, int> downUpLimit = getGlobalBandwidthLimits();
-    session->setGlobalDownloadSpeedLimit(downUpLimit.first);
-    session->setGlobalUploadSpeedLimit(downUpLimit.second);
+    session->setGlobalDownloadSpeedLimit(m_ui->spinDownloadLimit->value() * 1024);
+    session->setGlobalUploadSpeedLimit(m_ui->spinUploadLimit->value() * 1024);
+    session->setAltGlobalDownloadSpeedLimit(m_ui->spinDownloadLimitAlt->value() * 1024);
+    session->setAltGlobalUploadSpeedLimit(m_ui->spinUploadLimitAlt->value() * 1024);
     session->setUTPRateLimited(m_ui->checkLimituTPConnections->isChecked());
     session->setIncludeOverheadInLimits(m_ui->checkLimitTransportOverhead->isChecked());
     session->setIgnoreLimitsOnLAN(!m_ui->checkLimitLocalPeerRate->isChecked());
-    const QPair<int, int> altDownUpLimit = getAltGlobalBandwidthLimits();
-    session->setAltGlobalDownloadSpeedLimit(altDownUpLimit.first);
-    session->setAltGlobalUploadSpeedLimit(altDownUpLimit.second);
     pref->setSchedulerStartTime(m_ui->timeEditScheduleFrom->time());
     pref->setSchedulerEndTime(m_ui->timeEditScheduleTo->time());
     pref->setSchedulerDays(static_cast<SchedulerDays>(m_ui->comboBoxScheduleDays->currentIndex()));
@@ -723,6 +734,7 @@ void OptionsDialog::saveOptions()
         // Security
         pref->setWebUiClickjackingProtectionEnabled(m_ui->checkClickjacking->isChecked());
         pref->setWebUiCSRFProtectionEnabled(m_ui->checkCSRFProtection->isChecked());
+        pref->setWebUIHostHeaderValidationEnabled(m_ui->groupHostHeaderValidation->isChecked());
         // DynDNS
         pref->setDynDNSEnabled(m_ui->checkDynDNS->isChecked());
         pref->setDynDNSService(m_ui->comboDNSService->currentIndex());
@@ -736,7 +748,7 @@ void OptionsDialog::saveOptions()
     // End Web UI
     // End preferences
     // Save advanced settings
-    advancedSettings->saveAdvancedSettings();
+    m_advancedSettings->saveAdvancedSettings();
     // Assume that user changed multiple settings
     // so it's best to save immediately
     pref->apply();
@@ -829,6 +841,7 @@ void OptionsDialog::loadOptions()
     m_ui->checkRSSEnable->setChecked(RSS::Session::instance()->isProcessingEnabled());
     m_ui->checkRSSAutoDownloaderEnable->setChecked(RSS::AutoDownloader::instance()->isProcessingEnabled());
     m_ui->textSmartEpisodeFilters->setPlainText(RSS::AutoDownloader::instance()->smartEpisodeFilters().join('\n'));
+    m_ui->checkSmartFilterDownloadRepacks->setChecked(RSS::AutoDownloader::instance()->downloadRepacks());
 
     m_ui->spinRSSRefreshInterval->setValue(RSS::Session::instance()->refreshInterval());
     m_ui->spinRSSMaxArticlesPerFeed->setValue(RSS::Session::instance()->maxArticlesPerFeed());
@@ -1007,55 +1020,10 @@ void OptionsDialog::loadOptions()
     // End Connection preferences
 
     // Speed preferences
-    intValue = session->globalDownloadSpeedLimit() / 1024;
-    if (intValue > 0) {
-        // Enabled
-        m_ui->checkDownloadLimit->setChecked(true);
-        m_ui->spinDownloadLimit->setEnabled(true);
-        m_ui->spinDownloadLimit->setValue(intValue);
-    }
-    else {
-        // Disabled
-        m_ui->checkDownloadLimit->setChecked(false);
-        m_ui->spinDownloadLimit->setEnabled(false);
-    }
-    intValue = session->globalUploadSpeedLimit() / 1024;
-    if (intValue > 0) {
-        // Enabled
-        m_ui->checkUploadLimit->setChecked(true);
-        m_ui->spinUploadLimit->setEnabled(true);
-        m_ui->spinUploadLimit->setValue(intValue);
-    }
-    else {
-        // Disabled
-        m_ui->checkUploadLimit->setChecked(false);
-        m_ui->spinUploadLimit->setEnabled(false);
-    }
-
-    intValue = session->altGlobalDownloadSpeedLimit() / 1024;
-    if (intValue > 0) {
-        // Enabled
-        m_ui->checkDownloadLimitAlt->setChecked(true);
-        m_ui->spinDownloadLimitAlt->setEnabled(true);
-        m_ui->spinDownloadLimitAlt->setValue(intValue);
-    }
-    else {
-        // Disabled
-        m_ui->checkDownloadLimitAlt->setChecked(false);
-        m_ui->spinDownloadLimitAlt->setEnabled(false);
-    }
-    intValue = session->altGlobalUploadSpeedLimit() / 1024;
-    if (intValue > 0) {
-        // Enabled
-        m_ui->checkUploadLimitAlt->setChecked(true);
-        m_ui->spinUploadLimitAlt->setEnabled(true);
-        m_ui->spinUploadLimitAlt->setValue(intValue);
-    }
-    else {
-        // Disabled
-        m_ui->checkUploadLimitAlt->setChecked(false);
-        m_ui->spinUploadLimitAlt->setEnabled(false);
-    }
+    m_ui->spinDownloadLimit->setValue(session->globalDownloadSpeedLimit() / 1024);
+    m_ui->spinUploadLimit->setValue(session->globalUploadSpeedLimit() / 1024);
+    m_ui->spinDownloadLimitAlt->setValue(session->altGlobalDownloadSpeedLimit() / 1024);
+    m_ui->spinUploadLimitAlt->setValue(session->altGlobalUploadSpeedLimit() / 1024);
 
     m_ui->checkLimituTPConnections->setChecked(session->isUTPRateLimited());
     m_ui->checkLimitTransportOverhead->setChecked(session->includeOverheadInLimits());
@@ -1130,6 +1098,7 @@ void OptionsDialog::loadOptions()
     // Security
     m_ui->checkClickjacking->setChecked(pref->isWebUiClickjackingProtectionEnabled());
     m_ui->checkCSRFProtection->setChecked(pref->isWebUiCSRFProtectionEnabled());
+    m_ui->groupHostHeaderValidation->setChecked(pref->isWebUIHostHeaderValidationEnabled());
 
     m_ui->checkDynDNS->setChecked(pref->isDynDNSEnabled());
     m_ui->comboDNSService->setCurrentIndex(static_cast<int>(pref->getDynDNSService()));
@@ -1195,30 +1164,6 @@ bool OptionsDialog::isUPnPEnabled() const
     return m_ui->checkUPnP->isChecked();
 }
 
-// Return Download & Upload limits in kbps
-// [download,upload]
-QPair<int, int> OptionsDialog::getGlobalBandwidthLimits() const
-{
-    int DL = 0, UP = 0;
-    if (m_ui->checkDownloadLimit->isChecked())
-        DL = m_ui->spinDownloadLimit->value() * 1024;
-    if (m_ui->checkUploadLimit->isChecked())
-        UP = m_ui->spinUploadLimit->value() * 1024;
-    return qMakePair(DL, UP);
-}
-
-// Return alternate Download & Upload limits in kbps
-// [download,upload]
-QPair<int, int> OptionsDialog::getAltGlobalBandwidthLimits() const
-{
-    int DL = 0, UP = 0;
-    if (m_ui->checkDownloadLimitAlt->isChecked())
-        DL = m_ui->spinDownloadLimitAlt->value() * 1024;
-    if (m_ui->checkUploadLimitAlt->isChecked())
-        UP = m_ui->spinUploadLimitAlt->value() * 1024;
-    return qMakePair(DL, UP);
-}
-
 bool OptionsDialog::startMinimized() const
 {
     return m_ui->checkStartMinimized->isChecked();
@@ -1295,7 +1240,7 @@ int OptionsDialog::getMaxUploadsPerTorrent() const
 
 void OptionsDialog::on_buttonBox_accepted()
 {
-    if (applyButton->isEnabled()) {
+    if (m_applyButton->isEnabled()) {
         if (!schedTimesOk()) {
             m_ui->tabSelection->setCurrentRow(TAB_SPEED);
             return;
@@ -1304,7 +1249,11 @@ void OptionsDialog::on_buttonBox_accepted()
             m_ui->tabSelection->setCurrentRow(TAB_WEBUI);
             return;
         }
-        applyButton->setEnabled(false);
+        if (!isAlternativeWebUIPathValid()) {
+            m_ui->tabSelection->setCurrentRow(TAB_WEBUI);
+            return;
+        }
+        m_applyButton->setEnabled(false);
         this->hide();
         saveOptions();
     }
@@ -1314,7 +1263,7 @@ void OptionsDialog::on_buttonBox_accepted()
 
 void OptionsDialog::applySettings(QAbstractButton *button)
 {
-    if (button == applyButton) {
+    if (button == m_applyButton) {
         if (!schedTimesOk()) {
             m_ui->tabSelection->setCurrentRow(TAB_SPEED);
             return;
@@ -1323,6 +1272,10 @@ void OptionsDialog::applySettings(QAbstractButton *button)
             m_ui->tabSelection->setCurrentRow(TAB_WEBUI);
             return;
         }
+        if (!isAlternativeWebUIPathValid()) {
+            m_ui->tabSelection->setCurrentRow(TAB_WEBUI);
+            return;
+        }
         saveOptions();
     }
 }
@@ -1346,7 +1299,7 @@ bool OptionsDialog::useAdditionDialog() const
 
 void OptionsDialog::enableApplyButton()
 {
-    applyButton->setEnabled(true);
+    m_applyButton->setEnabled(true);
 }
 
 void OptionsDialog::toggleComboRatioLimitAct()
@@ -1541,7 +1494,7 @@ void OptionsDialog::on_addScanFolderButton_clicked()
             break;
         default:
             pref->setScanDirsLastPath(dir);
-            addedScanDirs << dir;
+            m_addedScanDirs << dir;
             for (int i = 0; i < ScanFoldersModel::instance()->columnCount(); ++i)
                 m_ui->scanFoldersView->resizeColumnToContents(i);
             enableApplyButton();
@@ -1559,9 +1512,9 @@ void OptionsDialog::on_removeScanFolderButton_clicked()
     if (selected.isEmpty())
         return;
     Q_ASSERT(selected.count() == ScanFoldersModel::instance()->columnCount());
-    foreach (const QModelIndex &index, selected) {
+    for (const QModelIndex &index : selected) {
         if (index.column() == ScanFoldersModel::WATCH)
-            removedScanDirs << index.data().toString();
+            m_removedScanDirs << index.data().toString();
     }
     ScanFoldersModel::instance()->removePath(selected.first().row(), false);
 }
@@ -1805,6 +1758,15 @@ bool OptionsDialog::webUIAuthenticationOk()
     return true;
 }
 
+bool OptionsDialog::isAlternativeWebUIPathValid()
+{
+    if (m_ui->groupAltWebUI->isChecked() && m_ui->textWebUIRootFolder->selectedPath().trimmed().isEmpty()) {
+        QMessageBox::warning(this, tr("Location Error"), tr("The alternative Web UI files location cannot be blank."));
+        return false;
+    }
+    return true;
+}
+
 void OptionsDialog::on_banListButton_clicked()
 {
     // call dialog window
