@@ -40,6 +40,7 @@
 #include <QWheelEvent>
 
 #include "base/bittorrent/peerinfo.h"
+#include "base/bittorrent/session.h"
 #include "base/bittorrent/torrenthandle.h"
 #include "base/logger.h"
 #include "base/net/geoipmanager.h"
@@ -102,7 +103,7 @@ PeerListWidget::PeerListWidget(PropertiesWidget *parent)
         hideColumn(PeerListDelegate::COUNTRY);
     // Ensure that at least one column is visible at all times
     bool atLeastOne = false;
-    for (unsigned int i = 0; i < PeerListDelegate::IP_HIDDEN; ++i) {
+    for (int i = 0; i < PeerListDelegate::IP_HIDDEN; ++i) {
         if (!isColumnHidden(i)) {
             atLeastOne = true;
             break;
@@ -113,7 +114,7 @@ PeerListWidget::PeerListWidget(PropertiesWidget *parent)
     // To also mitigate the above issue, we have to resize each column when
     // its size is 0, because explicitly 'showing' the column isn't enough
     // in the above scenario.
-    for (unsigned int i = 0; i < PeerListDelegate::IP_HIDDEN; ++i)
+    for (int i = 0; i < PeerListDelegate::IP_HIDDEN; ++i)
         if ((columnWidth(i) <= 0) && !isColumnHidden(i))
             resizeColumnToContents(i);
     // Context menu
@@ -168,7 +169,7 @@ void PeerListWidget::displayToggleColumnsMenu(const QPoint &)
         actions.append(myAct);
     }
     int visibleCols = 0;
-    for (unsigned int i = 0; i < PeerListDelegate::IP_HIDDEN; ++i) {
+    for (int i = 0; i < PeerListDelegate::IP_HIDDEN; ++i) {
         if (!isColumnHidden(i))
             ++visibleCols;
 
@@ -247,9 +248,9 @@ void PeerListWidget::showPeerListMenu(const QPoint &)
     if (!act) return;
 
     if (act == addPeerAct) {
-        QList<BitTorrent::PeerAddress> peersList = PeersAdditionDialog::askForPeers(this);
+        const QList<BitTorrent::PeerAddress> peersList = PeersAdditionDialog::askForPeers(this);
         int peerCount = 0;
-        foreach (const BitTorrent::PeerAddress &addr, peersList) {
+        for (const BitTorrent::PeerAddress &addr : peersList) {
             if (torrent->connectPeer(addr)) {
                 qDebug("Adding peer %s...", qUtf8Printable(addr.ip.toString()));
                 Logger::instance()->addMessage(tr("Manually adding peer '%1'...").arg(addr.ip.toString()));
@@ -283,8 +284,8 @@ void PeerListWidget::banSelectedPeers()
                                     QString(), 0, 1);
     if (ret) return;
 
-    QModelIndexList selectedIndexes = selectionModel()->selectedRows();
-    foreach (const QModelIndex &index, selectedIndexes) {
+    const QModelIndexList selectedIndexes = selectionModel()->selectedRows();
+    for (const QModelIndex &index : selectedIndexes) {
         int row = m_proxyModel->mapToSource(index).row();
         QString ip = m_listModel->data(m_listModel->index(row, PeerListDelegate::IP_HIDDEN)).toString();
         qDebug("Banning peer %s...", ip.toLocal8Bit().data());
@@ -297,9 +298,9 @@ void PeerListWidget::banSelectedPeers()
 
 void PeerListWidget::copySelectedPeers()
 {
-    QModelIndexList selectedIndexes = selectionModel()->selectedRows();
+    const QModelIndexList selectedIndexes = selectionModel()->selectedRows();
     QStringList selectedPeers;
-    foreach (const QModelIndex &index, selectedIndexes) {
+    for (const QModelIndex &index : selectedIndexes) {
         int row = m_proxyModel->mapToSource(index).row();
         QString ip = m_listModel->data(m_listModel->index(row, PeerListDelegate::IP_HIDDEN)).toString();
         QString myport = m_listModel->data(m_listModel->index(row, PeerListDelegate::PORT)).toString();
@@ -320,7 +321,7 @@ void PeerListWidget::clear()
     int nbrows = m_listModel->rowCount();
     if (nbrows > 0) {
         qDebug("Cleared %d peers", nbrows);
-        m_listModel->removeRows(0,  nbrows);
+        m_listModel->removeRows(0, nbrows);
     }
 }
 
@@ -338,10 +339,10 @@ void PeerListWidget::loadPeers(BitTorrent::TorrentHandle *const torrent, bool fo
 {
     if (!torrent) return;
 
-    QList<BitTorrent::PeerInfo> peers = torrent->peers();
+    const QList<BitTorrent::PeerInfo> peers = torrent->peers();
     QSet<QString> oldPeersSet = m_peerItems.keys().toSet();
 
-    foreach (const BitTorrent::PeerInfo &peer, peers) {
+    for (const BitTorrent::PeerInfo &peer : peers) {
         BitTorrent::PeerAddress addr = peer.address();
         if (addr.ip.isNull()) continue;
 
