@@ -38,6 +38,7 @@
 #include <QThread>
 #include <QTimer>
 
+#include "base/bittorrent/filepriority.h"
 #include "base/bittorrent/session.h"
 #include "base/preferences.h"
 #include "base/unicodestrings.h"
@@ -140,9 +141,6 @@ PropertiesWidget::PropertiesWidget(QWidget *parent, MainWindow *mainWindow, Tran
     // Peers list
     m_peerList = new PeerListWidget(this);
     m_ui->vBoxLayoutPeerPage->addWidget(m_peerList);
-    // Speed widget
-    m_speedWidget = new SpeedWidget(this);
-    m_ui->speedLayout->addWidget(m_speedWidget);
     // Tab bar
     m_tabBar = new PropTabBar();
     m_tabBar->setContentsMargins(0, 5, 0, 0);
@@ -164,6 +162,9 @@ PropertiesWidget::PropertiesWidget(QWidget *parent, MainWindow *mainWindow, Tran
     connect(m_deleteHotkeyWeb, &QShortcut::activated, this, &PropertiesWidget::deleteSelectedUrlSeeds);
     m_openHotkeyFile = new QShortcut(Qt::Key_Return, m_ui->filesList, nullptr, nullptr, Qt::WidgetShortcut);
     connect(m_openHotkeyFile, &QShortcut::activated, this, &PropertiesWidget::openSelectedFile);
+
+    configure();
+    connect(Preferences::instance(), &Preferences::changed, this, &PropertiesWidget::configure);
 }
 
 PropertiesWidget::~PropertiesWidget()
@@ -288,11 +289,6 @@ QTreeView *PropertiesWidget::getFilesList() const
     return m_ui->filesList;
 }
 
-SpeedWidget *PropertiesWidget::getSpeedWidget() const
-{
-    return m_speedWidget;
-}
-
 void PropertiesWidget::updateSavePath(BitTorrent::TorrentHandle *const torrent)
 {
     if (torrent == m_torrent)
@@ -445,13 +441,15 @@ void PropertiesWidget::loadDynamicData()
                 .arg(QString::number(m_torrent->leechsCount())
                     , QString::number(m_torrent->totalLeechersCount())));
 
+            const int dlDuration = m_torrent->activeTime() - m_torrent->finishedTime();
+            const QString dlAvg = Utils::Misc::friendlyUnit((m_torrent->totalDownload() / ((dlDuration == 0) ? -1 : dlDuration)), true);
             m_ui->labelDlSpeedVal->setText(tr("%1 (%2 avg.)", "%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)")
-                .arg(Utils::Misc::friendlyUnit(m_torrent->downloadPayloadRate(), true)
-                    , Utils::Misc::friendlyUnit(m_torrent->totalDownload() / (1 + m_torrent->activeTime() - m_torrent->finishedTime()), true)));
+                .arg(Utils::Misc::friendlyUnit(m_torrent->downloadPayloadRate(), true), dlAvg));
 
+            const int ulDuration = m_torrent->activeTime();
+            const QString ulAvg = Utils::Misc::friendlyUnit((m_torrent->totalUpload() / ((ulDuration == 0) ? -1 : ulDuration)), true);
             m_ui->labelUpSpeedVal->setText(tr("%1 (%2 avg.)", "%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)")
-                .arg(Utils::Misc::friendlyUnit(m_torrent->uploadPayloadRate(), true)
-                    , Utils::Misc::friendlyUnit(m_torrent->totalUpload() / (1 + m_torrent->activeTime()), true)));
+                .arg(Utils::Misc::friendlyUnit(m_torrent->uploadPayloadRate(), true), ulAvg));
 
             m_ui->labelLastSeenCompleteVal->setText(m_torrent->lastSeenComplete().isValid() ? m_torrent->lastSeenComplete().toString(Qt::DefaultLocaleShortDate) : tr("Never"));
 
@@ -514,7 +512,7 @@ void PropertiesWidget::loadUrlSeeds()
     qDebug("Loading URL seeds");
     const QList<QUrl> hcSeeds = m_torrent->urlSeeds();
     // Add url seeds
-    foreach (const QUrl &hcSeed, hcSeeds) {
+    for (const QUrl &hcSeed : hcSeeds) {
         qDebug("Loading URL seed: %s", qUtf8Printable(hcSeed.toString()));
         new QListWidgetItem(hcSeed.toString(), m_ui->listWebSeeds);
     }
@@ -585,7 +583,7 @@ void PropertiesWidget::displayFilesListMenu(const QPoint &)
 {
     if (!m_torrent) return;
 
-    QModelIndexList selectedRows = m_ui->filesList->selectionModel()->selectedRows(0);
+    const QModelIndexList selectedRows = m_ui->filesList->selectionModel()->selectedRows(0);
     if (selectedRows.empty()) return;
 
     QMenu myFilesLlistMenu;
@@ -624,18 +622,18 @@ void PropertiesWidget::displayFilesListMenu(const QPoint &)
         renameSelectedFile();
     }
     else {
-        int prio = prio::NORMAL;
+        BitTorrent::FilePriority prio = BitTorrent::FilePriority::Normal;
         if (act == m_ui->actionHigh)
-            prio = prio::HIGH;
+            prio = BitTorrent::FilePriority::High;
         else if (act == m_ui->actionMaximum)
-            prio = prio::MAXIMUM;
+            prio = BitTorrent::FilePriority::Maximum;
         else if (act == m_ui->actionNotDownloaded)
-            prio = prio::IGNORED;
+            prio = BitTorrent::FilePriority::Ignored;
 
         qDebug("Setting files priority");
-        foreach (QModelIndex index, selectedRows) {
-            qDebug("Setting priority(%d) for file at row %d", prio, index.row());
-            m_propListModel->setData(m_propListModel->index(index.row(), PRIORITY, index.parent()), prio);
+        for (const QModelIndex &index : selectedRows) {
+            qDebug("Setting priority(%d) for file at row %d", static_cast<int>(prio), index.row());
+            m_propListModel->setData(m_propListModel->index(index.row(), PRIORITY, index.parent()), static_cast<int>(prio));
         }
         // Save changes
         filteredFilesChanged();
@@ -800,6 +798,29 @@ void PropertiesWidget::openSelectedFile()
     openDoubleClickedFile(selectedIndexes.first());
 }
 
+void PropertiesWidget::configure()
+{
+    // Speed widget
+    if (Preferences::instance()->isSpeedWidgetEnabled()) {
+        if (!m_speedWidget || !qobject_cast<SpeedWidget *>(m_speedWidget)) {
+            m_ui->speedLayout->removeWidget(m_speedWidget);
+            delete m_speedWidget;
+            m_speedWidget = new SpeedWidget {this};
+            m_ui->speedLayout->addWidget(m_speedWidget);
+        }
+    }
+    else {
+        if (!m_speedWidget || !qobject_cast<QLabel *>(m_speedWidget)) {
+            m_ui->speedLayout->removeWidget(m_speedWidget);
+            delete m_speedWidget;
+            auto *label = new QLabel(tr("<center><b>Speed graphs are disabled</b><p>You may change this setting in Advanced Options </center>"), this);
+            label->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+            m_speedWidget = label;
+            m_ui->speedLayout->addWidget(m_speedWidget);
+        }
+    }
+}
+
 void PropertiesWidget::askWebSeed()
 {
     bool ok;
@@ -827,7 +848,7 @@ void PropertiesWidget::deleteSelectedUrlSeeds()
     if (selectedItems.isEmpty()) return;
 
     QList<QUrl> urlSeeds;
-    foreach (const QListWidgetItem *item, selectedItems)
+    for (const QListWidgetItem *item : selectedItems)
         urlSeeds << item->text();
 
     m_torrent->removeUrlSeeds(urlSeeds);
@@ -841,7 +862,7 @@ void PropertiesWidget::copySelectedWebSeedsToClipboard() const
     if (selectedItems.isEmpty()) return;
 
     QStringList urlsToCopy;
-    foreach (QListWidgetItem *item, selectedItems)
+    for (const QListWidgetItem *item : selectedItems)
         urlsToCopy << item->text();
 
     QApplication::clipboard()->setText(urlsToCopy.join('\n'));
