@@ -28,20 +28,131 @@
 
 #include "speedplotview.h"
 
+#include <QLocale>
 #include <QPainter>
 #include <QPen>
 #include "base/global.h"
+#include "base/unicodestrings.h"
 #include "base/utils/misc.h"
 
+namespace
+{
+    enum PeriodInSeconds
+    {
+        MIN1_SEC = 60,
+        MIN5_SEC = 5 * 60,
+        MIN30_SEC = 30 * 60,
+        HOUR6_SEC = 6 * 60 * 60
+    };
+
+    const int MIN5_BUF_SIZE = 5 * 60;
+    const int MIN30_BUF_SIZE = 5 * 60;
+    const int HOUR6_BUF_SIZE = 5 * 60;
+    const int DIVIDER_30MIN = MIN30_SEC / MIN30_BUF_SIZE;
+    const int DIVIDER_6HOUR = HOUR6_SEC / HOUR6_BUF_SIZE;
+
+
+    // table of supposed nice steps for grid marks to get nice looking quarters of scale
+    const double roundingTable[] = {1.2, 1.6, 2, 2.4, 2.8, 3.2, 4, 6, 8};
+
+    struct SplittedValue
+    {
+        double arg;
+        Utils::Misc::SizeUnit unit;
+        qint64 sizeInBytes() const
+        {
+            return Utils::Misc::sizeInBytes(arg, unit);
+        }
+    };
+
+    SplittedValue getRoundedYScale(double value)
+    {
+        using Utils::Misc::SizeUnit;
+
+        if (value == 0.0) return {0, SizeUnit::Byte};
+        if (value <= 12.0) return {12, SizeUnit::Byte};
+
+        SizeUnit calculatedUnit = SizeUnit::Byte;
+        while (value > 1024) {
+            value /= 1024;
+            calculatedUnit = static_cast<SizeUnit>(static_cast<int>(calculatedUnit) + 1);
+        }
+
+        if (value > 100.0) {
+            int roundedValue = static_cast<int>(value / 40) * 40;
+            while (roundedValue < value)
+                roundedValue += 40;
+            return {static_cast<double>(roundedValue), calculatedUnit};
+        }
+
+        if (value > 10.0) {
+            int roundedValue = static_cast<int>(value / 4) * 4;
+            while (roundedValue < value)
+                roundedValue += 4;
+            return {static_cast<double>(roundedValue), calculatedUnit};
+        }
+
+        for (const auto &roundedValue : roundingTable) {
+            if (value <= roundedValue)
+                return {roundedValue, calculatedUnit};
+        }
+        return {10.0, calculatedUnit};
+    }
+
+    QString formatLabel(const double argValue, const Utils::Misc::SizeUnit unit)
+    {
+        // check is there need for digits after decimal separator
+        const int precision = (argValue < 10) ? friendlyUnitPrecision(unit) : 0;
+        return QLocale::system().toString(argValue, 'f', precision)
+               + QString::fromUtf8(C_NON_BREAKING_SPACE)
+               + unitString(unit, true);
+    }
+}
+
+SpeedPlotView::Averager::Averager(int divider, boost::circular_buffer<PointData> &sink)
+    : m_divider(divider)
+    , m_sink(sink)
+    , m_counter(0)
+    , m_accumulator {}
+{
+}
+
+void SpeedPlotView::Averager::push(const PointData &pointData)
+{
+    // Accumulator overflow will be hit in worst case on longest used averaging span,
+    // defined by divider value. Maximum divider is DIVIDER_6HOUR = 72
+    // Using int32 for accumulator we get overflow when transfer speed reaches 2^31/72 ~~ 28.4 MBytes/s.
+    // With quint64 this speed limit is 2^64/72 ~~ 228 PBytes/s.
+    // This speed is inaccessible to an ordinary user.
+    m_accumulator.x += pointData.x;
+    for (int id = UP; id < NB_GRAPHS; ++id)
+        m_accumulator.y[id] += pointData.y[id];
+    m_counter = (m_counter + 1) % m_divider;
+    if (m_counter != 0)
+        return; // still accumulating
+    // it is time final averaging calculations
+    for (int id = UP; id < NB_GRAPHS; ++id)
+        m_accumulator.y[id] /= m_divider;
+    m_accumulator.x /= m_divider;
+    // now flush out averaged data
+    m_sink.push_back(m_accumulator);
+    m_accumulator = {};
+}
+
+bool SpeedPlotView::Averager::isReady() const
+{
+    return m_counter == 0;
+}
+
 SpeedPlotView::SpeedPlotView(QWidget *parent)
     : QGraphicsView(parent)
     , m_data5Min(MIN5_BUF_SIZE)
     , m_data30Min(MIN30_BUF_SIZE)
     , m_data6Hour(HOUR6_BUF_SIZE)
+    , m_averager30Min(DIVIDER_30MIN, m_data30Min)
+    , m_averager6Hour(DIVIDER_6HOUR, m_data6Hour)
     , m_period(MIN5)
     , m_viewablePointsCount(MIN5_SEC)
-    , m_counter30Min(-1)
-    , m_counter6Hour(-1)
 {
     QPen greenPen;
     greenPen.setWidthF(1.5);
@@ -80,30 +191,11 @@ void SpeedPlotView::setGraphEnable(GraphID id, bool enable)
     viewport()->update();
 }
 
-void SpeedPlotView::pushPoint(SpeedPlotView::PointData point)
+void SpeedPlotView::pushPoint(const SpeedPlotView::PointData &point)
 {
-    m_counter30Min = (m_counter30Min + 1) % 3;
-    m_counter6Hour = (m_counter6Hour + 1) % 18;
-
     m_data5Min.push_back(point);
-
-    if (m_counter30Min == 0) {
-        m_data30Min.push_back(point);
-    }
-    else {
-        m_data30Min.back().x = (m_data30Min.back().x * m_counter30Min + point.x) / (m_counter30Min + 1);
-        for (int id = UP; id < NB_GRAPHS; ++id)
-            m_data30Min.back().y[id] = (m_data30Min.back().y[id] * m_counter30Min + point.y[id]) / (m_counter30Min + 1);
-    }
-
-    if (m_counter6Hour == 0) {
-        m_data6Hour.push_back(point);
-    }
-    else {
-        m_data6Hour.back().x = (m_data6Hour.back().x * m_counter6Hour + point.x) / (m_counter6Hour + 1);
-        for (int id = UP; id < NB_GRAPHS; ++id)
-            m_data6Hour.back().y[id] = (m_data6Hour.back().y[id] * m_counter6Hour + point.y[id]) / (m_counter6Hour + 1);
-    }
+    m_averager30Min.push(point);
+    m_averager6Hour.push(point);
 }
 
 void SpeedPlotView::setViewableLastPoints(TimePeriod period)
@@ -132,8 +224,8 @@ void SpeedPlotView::replot()
 {
     if ((m_period == MIN1)
         || (m_period == MIN5)
-        || ((m_period == MIN30) && (m_counter30Min == 2))
-        || ((m_period == HOUR6) && (m_counter6Hour == 17)))
+        || ((m_period == MIN30) && m_averager30Min.isReady())
+        || ((m_period == HOUR6) && m_averager6Hour.isReady()) )
         viewport()->update();
 }
 
@@ -151,11 +243,11 @@ boost::circular_buffer<SpeedPlotView::PointData> &SpeedPlotView::getCurrentData(
     }
 }
 
-int SpeedPlotView::maxYValue()
+quint64 SpeedPlotView::maxYValue()
 {
     boost::circular_buffer<PointData> &queue = getCurrentData();
 
-    int maxYValue = 0;
+    quint64 maxYValue = 0;
     for (int id = UP; id < NB_GRAPHS; ++id) {
 
         if (!m_properties[static_cast<GraphID>(id)].enable)
@@ -178,18 +270,16 @@ void SpeedPlotView::paintEvent(QPaintEvent *)
     QFontMetrics fontMetrics = painter.fontMetrics();
 
     rect.adjust(4, 4, 0, -4); // Add padding
-
-    int maxY = maxYValue();
-
+    const SplittedValue niceScale = getRoundedYScale(maxYValue());
     rect.adjust(0, fontMetrics.height(), 0, 0); // Add top padding for top speed text
 
     // draw Y axis speed labels
-    QVector<QString> speedLabels = {
-        Utils::Misc::friendlyUnit(maxY, true),
-        Utils::Misc::friendlyUnit(0.75 * maxY, true),
-        Utils::Misc::friendlyUnit(0.5 * maxY, true),
-        Utils::Misc::friendlyUnit(0.25 * maxY, true),
-        Utils::Misc::friendlyUnit(0, true)
+    const QVector<QString> speedLabels = {
+        formatLabel(niceScale.arg, niceScale.unit),
+        formatLabel((0.75 * niceScale.arg), niceScale.unit),
+        formatLabel((0.50 * niceScale.arg), niceScale.unit),
+        formatLabel((0.25 * niceScale.arg), niceScale.unit),
+        formatLabel(0.0, niceScale.unit),
     };
 
     int yAxisWidth = 0;
@@ -231,8 +321,8 @@ void SpeedPlotView::paintEvent(QPaintEvent *)
     // draw graphs
     rect.adjust(3, 0, 0, 0); // Need, else graphs cross left gridline
 
-    double yMultiplier = (maxY == 0) ? 0.0 : static_cast<double>(rect.height()) / maxY;
-    double xTickSize = static_cast<double>(rect.width()) / m_viewablePointsCount;
+    const double yMultiplier = (niceScale.arg == 0.0) ? 0.0 : (static_cast<double>(rect.height()) / niceScale.sizeInBytes());
+    const double xTickSize = static_cast<double>(rect.width()) / m_viewablePointsCount;
 
     boost::circular_buffer<PointData> &queue = getCurrentData();
 
@@ -258,12 +348,12 @@ void SpeedPlotView::paintEvent(QPaintEvent *)
 
     double legendHeight = 0;
     int legendWidth = 0;
-    for (const auto &property : qAsConst(m_properties)) {
+    for (const auto &property : asConst(m_properties)) {
         if (!property.enable)
             continue;
 
         if (fontMetrics.width(property.name) > legendWidth)
-            legendWidth =  fontMetrics.width(property.name);
+            legendWidth = fontMetrics.width(property.name);
         legendHeight += 1.5 * fontMetrics.height();
     }
 
@@ -273,7 +363,7 @@ void SpeedPlotView::paintEvent(QPaintEvent *)
     painter.fillRect(legendBackgroundRect, legendBackgroundColor);
 
     i = 0;
-    for (const auto &property : qAsConst(m_properties)) {
+    for (const auto &property : asConst(m_properties)) {
         if (!property.enable)
             continue;
 
