@@ -29,15 +29,19 @@
 #include "synccontroller.h"
 
 #include <QJsonObject>
+#include <QThread>
+#include <QTimer>
 
 #include "base/bittorrent/peerinfo.h"
 #include "base/bittorrent/session.h"
 #include "base/bittorrent/torrenthandle.h"
+#include "base/global.h"
 #include "base/net/geoipmanager.h"
 #include "base/preferences.h"
 #include "base/utils/fs.h"
 #include "base/utils/string.h"
 #include "apierror.h"
+#include "freediskspacechecker.h"
 #include "isessionmanager.h"
 #include "serialize/serialize_torrent.h"
 
@@ -75,6 +79,7 @@ const char KEY_TRANSFER_UPDATA[] = "up_info_data";
 const char KEY_TRANSFER_UPRATELIMIT[] = "up_rate_limit";
 const char KEY_TRANSFER_DHT_NODES[] = "dht_nodes";
 const char KEY_TRANSFER_CONNECTION_STATUS[] = "connection_status";
+const char KEY_TRANSFER_FREESPACEONDISK[] = "free_space_on_disk";
 
 // Statistics keys
 const char KEY_TRANSFER_ALLTIME_DL[] = "alltime_dl";
@@ -94,6 +99,8 @@ const char KEY_FULL_UPDATE[] = "full_update";
 const char KEY_RESPONSE_ID[] = "rid";
 const char KEY_SUFFIX_REMOVED[] = "_removed";
 
+const int FREEDISKSPACE_CHECK_TIMEOUT = 30000;
+
 namespace
 {
     void processMap(const QVariantMap &prevData, const QVariantMap &data, QVariantMap &syncData);
@@ -127,7 +134,7 @@ namespace
 
         // num_peers is not reliable (adds up peers, which didn't even overcome tcp handshake)
         quint32 peers = 0;
-        foreach (BitTorrent::TorrentHandle *const torrent, BitTorrent::Session::instance()->torrents())
+        for (BitTorrent::TorrentHandle *const torrent : asConst(BitTorrent::Session::instance()->torrents()))
             peers += torrent->peersCount();
         map[KEY_TRANSFER_WRITE_CACHE_OVERLOAD] = ((sessionStatus.diskWriteQueue > 0) && (peers > 0)) ? Utils::String::fromDouble((100. * sessionStatus.diskWriteQueue) / peers, 2) : "0";
         map[KEY_TRANSFER_READ_CACHE_OVERLOAD] = ((sessionStatus.diskReadQueue > 0) && (peers > 0)) ? Utils::String::fromDouble((100. * sessionStatus.diskReadQueue) / peers, 2) : "0";
@@ -262,7 +269,7 @@ namespace
             syncData = data;
         }
         else {
-            foreach (QVariant item, data) {
+            for (const QVariant &item : data) {
                 if (!prevData.contains(item))
                     // new list item found - append it to syncData
                     syncData.append(item);
@@ -312,6 +319,27 @@ namespace
     }
 }
 
+SyncController::SyncController(ISessionManager *sessionManager, QObject *parent)
+    : APIController(sessionManager, parent)
+{
+    m_freeDiskSpaceThread = new QThread(this);
+    m_freeDiskSpaceChecker = new FreeDiskSpaceChecker();
+    m_freeDiskSpaceChecker->moveToThread(m_freeDiskSpaceThread);
+
+    connect(m_freeDiskSpaceThread, &QThread::finished, m_freeDiskSpaceChecker, &QObject::deleteLater);
+    connect(m_freeDiskSpaceChecker, &FreeDiskSpaceChecker::checked, this, &SyncController::freeDiskSpaceSizeUpdated);
+
+    m_freeDiskSpaceThread->start();
+    QTimer::singleShot(0, m_freeDiskSpaceChecker, &FreeDiskSpaceChecker::check);
+    m_freeDiskSpaceElapsedTimer.start();
+}
+
+SyncController::~SyncController()
+{
+    m_freeDiskSpaceThread->quit();
+    m_freeDiskSpaceThread->wait();
+}
+
 // The function returns the changed data from the server to synchronize with the web client.
 // Return value is map in JSON format.
 // Map contain the key:
@@ -369,6 +397,7 @@ namespace
 //  - "up_rate_limit: upload speed limit
 //  - "queueing": priority system usage flag
 //  - "refresh_interval": torrents table refresh interval
+//  - "free_space_on_disk": Free space on the default save path
 // GET param:
 //   - rid (int): last response id
 void SyncController::maindataAction()
@@ -381,7 +410,7 @@ void SyncController::maindataAction()
 
     BitTorrent::Session *const session = BitTorrent::Session::instance();
 
-    foreach (BitTorrent::TorrentHandle *const torrent, session->torrents()) {
+    for (BitTorrent::TorrentHandle *const torrent : asConst(session->torrents())) {
         QVariantMap map = serialize(*torrent);
         map.remove(KEY_TORRENT_HASH);
 
@@ -412,6 +441,7 @@ void SyncController::maindataAction()
     data["categories"] = categories;
 
     QVariantMap serverState = getTranserInfo();
+    serverState[KEY_TRANSFER_FREESPACEONDISK] = getFreeDiskSpace();
     serverState[KEY_SYNC_MAINDATA_QUEUEING] = session->isQueueingSystemEnabled();
     serverState[KEY_SYNC_MAINDATA_USE_ALT_SPEED_LIMITS] = session->isAltGlobalSpeedLimitEnabled();
     serverState[KEY_SYNC_MAINDATA_REFRESH_INTERVAL] = session->refreshInterval();
@@ -439,7 +469,7 @@ void SyncController::torrentPeersAction()
 
     QVariantMap data;
     QVariantHash peers;
-    QList<BitTorrent::PeerInfo> peersList = torrent->peers();
+    const QList<BitTorrent::PeerInfo> peersList = torrent->peers();
 #ifndef DISABLE_COUNTRIES_RESOLUTION
     bool resolvePeerCountries = Preferences::instance()->resolvePeerCountries();
 #else
@@ -448,7 +478,7 @@ void SyncController::torrentPeersAction()
 
     data[KEY_SYNC_TORRENT_PEERS_SHOW_FLAGS] = resolvePeerCountries;
 
-    foreach (const BitTorrent::PeerInfo &pi, peersList) {
+    for (const BitTorrent::PeerInfo &pi : peersList) {
         if (pi.address().ip.isNull()) continue;
         QVariantMap peer;
 #ifndef DISABLE_COUNTRIES_RESOLUTION
@@ -482,3 +512,18 @@ void SyncController::torrentPeersAction()
     sessionManager()->session()->setData(QLatin1String("syncTorrentPeersLastResponse"), lastResponse);
     sessionManager()->session()->setData(QLatin1String("syncTorrentPeersLastAcceptedResponse"), lastAcceptedResponse);
 }
+
+qint64 SyncController::getFreeDiskSpace()
+{
+    if (m_freeDiskSpaceElapsedTimer.hasExpired(FREEDISKSPACE_CHECK_TIMEOUT)) {
+        QTimer::singleShot(0, m_freeDiskSpaceChecker, &FreeDiskSpaceChecker::check);
+        m_freeDiskSpaceElapsedTimer.restart();
+    }
+
+    return m_freeDiskSpace;
+}
+
+void SyncController::freeDiskSpaceSizeUpdated(qint64 freeSpaceSize)
+{
+    m_freeDiskSpace = freeSpaceSize;
+}
